% GAUSS Gaussova radilana funkcija
%   GAUSS(X,Y) vrne vrednost Gaussove radialne funkcije v to"ckah X,Y

function val=gauss(X,Y);
  
  val = exp(-norm(X-Y,2)^2);
  
% MATRIKA_SISTEMA matrika sistema radialnih funkcij
%    MATRIKA_SISTEMA(pod, fun)
%    pod je matrika podatkov, fun ime radialne funkcije


function [A,b]=matrika_sistema(pod,fun);
%pod je tabela koordinat interpolacijskih tock [x1 y1 z1;x2 y2 z2;...]  
  N=size(pod,1);
  A=zeros(N);
  b=zeros(N,1);
  for i=1:N
    for j=1:N
      A(i,j)=feval(fun,pod(j,1:2),pod(i,1:2));
    end
    b(i)=pod(i,3);
  end
  
  
function y=quad(X,Y)
   y=1./(norm(X-Y)^2+1);
% RISI_GRAF 	narise graf interpolanta
%   RISI_GRAF(M,fun,nx)
%   M je matrika podatkov, fun ime funkcije, nx stevilo tock
%   v x smeri (pri risanju)

function risi_graf(M,fun,nx);
%funkcija narise ploskev, ki jo dobimo na podlagi matrike M
%fun je uporabnikova funkcija
%nx = stevilo tock risanja v x smeri
  [A,b]=matrika_sistema(M,fun);
  R=chol(A);
  y=R'\b;
  lambda=R\y;
  %dolocimo obmocje risanja
  % levi rob na x osi in se odmaknemo v levo za 20% 
  %celotnega obmocja na x osi
  %enako za y os
  pomikx=0.2*(max(M(:,1))-min(M(:,1)));
  pomiky=0.2*(max(M(:,2))-min(M(:,2)));
  xmin=min(M(:,1))-pomikx;
  xmax=max(M(:,1))+pomikx;
  ymin=min(M(:,2))-pomiky;
  ymax=max(M(:,2))+pomiky;
  %dolocimo gostoto mreze
  faktor=pomiky/pomikx;
  x=linspace(xmin,xmax,nx);
  y=linspace(ymin,ymax,round(faktor*nx));
  Z=vrednosti(x,y,lambda,M,fun);
  clf;
  colormap(winter);
  surf(x,y,Z); 
  hold on;
  plot3(M(:,1),M(:,2),M(:,3),'r.','MarkerSize',20)
  %surf(x,y,Z)
  hold off
  
  
  
% VREDNOSTI vrne vrednosti interpolacijske ploskve na mrezi
%    VREDNOSTI(x,y,lambda,pod,fun)
%    x,y dolocata mrezo, lambda koeficiente v interpolantu,
%    pod je tabela podatkov, fun ime funkcije, ki je osnova za 
%    interpolant
function Z=vrednosti(x,y,lambda,pod,fun);
  m=length(y);
  n=length(x);
  N=size(pod,1);
  for i=1:m
      for j=1:n
          vec=zeros(1,N);
          for k=1:N
            vec(k)=feval(fun,[x(j) y(i)],pod(k,1:2));
          end
          Z(i,j)=vec*lambda;    
      end
  end
